@@ -683,17 +683,16 @@ class TestSkim(TestBase):
     def test_reserved_options(self):
         options = [
             '--extended',
-            '--algo=TYPE',
             '--literal',
             '--no-mouse',
             '--cycle',
-            '--hscroll-off=COL',
+            '--hscroll-off=10',
             '--filepath-word',
             '--jump-labels=CHARS',
             '--border',
             '--inline-info',
             '--header=STR',
-            '--header-lines=N',
+            '--header-lines=1',
             '--no-bold',
             '--history-size=10',
             '--sync',
@@ -714,7 +713,7 @@ class TestSkim(TestBase):
         options = [
             '--bind=ctrl-a:cancel --bind ctrl-b:cancel',
             '--expect=ctrl-a --expect=ctrl-v',
-            '--tiebreak=index --tiebreak=score',
+            '--tiebreak=begin --tiebreak=score',
             '--cmd asdf --cmd find',
             '--query asdf -q xyz',
             '--delimiter , --delimiter . -d ,',
@@ -988,8 +987,30 @@ class TestSkim(TestBase):
         self.tmux.until(lambda lines: lines[-5].startswith(' >c'))
         self.tmux.until(lambda lines: lines[-4].startswith(' >b'))
         self.tmux.until(lambda lines: lines[-3].startswith('> a'))
+        self.tmux.send_keys(Key('C-h'))
+        self.tmux.until(lambda lines: lines[-4].startswith(' >b'))
+        self.tmux.until(lambda lines: lines[-3].startswith('> a'))
+        self.tmux.send_keys(Key('c'))
+        self.tmux.until(lambda lines: lines[-3].startswith('>>c'))
+        self.tmux.send_keys(Key('TAB'))
+        self.tmux.until(lambda lines: lines[-3].startswith('> c'))
+        self.tmux.send_keys(Key('C-h'))
+        self.tmux.until(lambda lines: lines[-5].startswith('  c'))
+        self.tmux.until(lambda lines: lines[-4].startswith(' >b'))
+        self.tmux.until(lambda lines: lines[-3].startswith('> a'))
+        self.tmux.send_keys(Key('C-h'))
+        self.tmux.until(lambda lines: lines[-4].startswith(' >b'))
+        self.tmux.until(lambda lines: lines[-3].startswith('> a'))
+        self.tmux.send_keys(Key('a'))
+        self.tmux.until(lambda lines: lines[-3].startswith('> a'))
+        self.tmux.send_keys(Key('TAB'))
+        self.tmux.until(lambda lines: lines[-3].startswith('>>a'))
+        self.tmux.send_keys(Key('C-h'))
+        self.tmux.until(lambda lines: lines[-5].startswith('  c'))
+        self.tmux.until(lambda lines: lines[-4].startswith(' >b'))
+        self.tmux.until(lambda lines: lines[-3].startswith('>>a'))
         self.tmux.send_keys(Key('Enter'))
-        self.assertEqual('b\nc', self.readonce().strip())
+        self.assertEqual('b\na', self.readonce().strip())
 
     def test_append_and_select(self):
         self.tmux.send_keys(f"""echo -n 'a\nb\nc' | {self.sk("-m --bind 'ctrl-f:append-and-select'")}""", Key('Enter'))
